$headerbar_button_gradient_a: gtkshade(desaturate($core_color_a, 15%), 1.15);
$headerbar_button_gradient_b: gtkshade(desaturate($core_color_a, 15%), 1.1);
$headerbar_button_gradient_c: gtkshade(desaturate($core_color_a, 15%), 1.08);
$headerbar_button_gradient_d: gtkshade(desaturate($core_color_a, 15%), 1.02);

$headerbar_button_hover_gradient_a: gtkshade(desaturate($core_color_a, 30%), 1.25);
$headerbar_button_hover_gradient_b: gtkshade(desaturate($core_color_a, 30%), 1.2);
$headerbar_button_hover_gradient_c: gtkshade(desaturate($core_color_a, 30%), 1.19);
$headerbar_button_hover_gradient_d: gtkshade(desaturate($core_color_a, 30%), 1.12);

$headerbar_button_backdrop_gradient_a: gtkshade(desaturate($core_color_a, 100%), 1.25);
$headerbar_button_backdrop_gradient_b: gtkshade(desaturate($core_color_a, 100%), 1.2);
$headerbar_button_backdrop_gradient_c: gtkshade(desaturate($core_color_a, 100%), 1.18);
$headerbar_button_backdrop_gradient_d: gtkshade(desaturate($core_color_a, 100%), 1.12);

$headerbar_button_backdrop_hover_gradient_a: gtkshade(desaturate($core_color_a, 100%), 1.3);
$headerbar_button_backdrop_hover_gradient_b: gtkshade(desaturate($core_color_a, 100%), 1.25);
$headerbar_button_backdrop_hover_gradient_c: gtkshade(desaturate($core_color_a, 100%), 1.23);
$headerbar_button_backdrop_hover_gradient_d: gtkshade(desaturate($core_color_a, 100%), 1.17);


headerbar {
    button {
        background-image: linear-gradient(to bottom, $headerbar_button_gradient_a, $headerbar_button_gradient_b 50%, $headerbar_button_gradient_c 50%, $headerbar_button_gradient_d);
        border-color: gtkshade(#a7bdd8, 0.6);
        &:hover {
            background-image: linear-gradient(to bottom, $headerbar_button_hover_gradient_a, $headerbar_button_hover_gradient_b 50%, $headerbar_button_hover_gradient_c 50%, $headerbar_button_hover_gradient_d);
            border-color: gtkshade(#a7bdd8, 0.6);
        }
        &:backdrop {
            background-image: linear-gradient(to bottom, $headerbar_button_backdrop_gradient_a, $headerbar_button_backdrop_gradient_b 50%, $headerbar_button_backdrop_gradient_c 50%, $headerbar_button_backdrop_gradient_d);
        }
        &:backdrop:hover {
            background-image: linear-gradient(to bottom, $headerbar_button_backdrop_hover_gradient_a, $headerbar_button_backdrop_hover_gradient_b 50%, $headerbar_button_backdrop_hover_gradient_c 50%, $headerbar_button_backdrop_hover_gradient_d);
            border-color: gtkshade(desaturate(#a7bdd8, 100%), 0.7);
        }
    }
}

