@import "palette";

/* set $ambiance to null, unless already defined */
$ambiance: null !default;

/***********
 * Tweak Tool *
 ***********/
 list.tweak-categories separator {
    // hide sidebar separators
    // make the sidebar look like a normal sidebar
    background: transparent;
  }

  /***********
   * Nautilus *
   ***********/
  .nautilus-window {
    .nautilus-canvas-item.dim-label,
    .nautilus-list-dim-label {
        color: mix($text_color, $base_color);
    }
    // keep details box visible
    // details box looks ugly when many items are selected and it floats above the orange
    background-image: none;
    background-color: if($variant=='light', white, $bg_color);
    &:backdrop { background-color: if($variant=='light',  $backdrop_base_color, $backdrop_bg_color); }

    placessidebar {
      background-color: if($variant=='light', $bg_color, $base_color);
      &:backdrop {
        background-color: $backdrop_bg_color;
      }
    }

    // Makes icons less bright in backdrop
    @at-root %dim_icons_in_backdrop,
    & *scrolledwindow:backdrop { opacity: 0.9; }

    infobar {
      background-color: if($variant=="light", lighten($silk, 10%), $slate);
      &:backdrop { background-color: $backdrop_bg_color; }
    }

    paned box.floating-bar {
      background-color: $bg_color;
      border-style: solid;
      border-color: if($variant=='light', lighten($borders_color, 8.3%), darken($borders_color, 1%));
      border-width: 1px 0 0 1px;
      border-radius: $button_radius 0 0 0;

      button:dir(ltr).circular.flat.image-button {
        background: radial-gradient(circle at 50%, white 35%, $bg_color 1%);
        color: $destructive_color;
      }

      button:dir(ltr).circular.flat.image-button:hover {
        border: 1px solid $borders_color;
        background: radial-gradient(circle at 50%, white 30%, $base_hover_color 16%);
        color: lighten($destructive_color, 5%);

      }
    }

    .searchbar-container searchbar {
      // get rid of a 1px white line shown at the top of the window
      // applies to the desktop too
      background: transparent;
      border-color: transparent;
    }

    treeview:drop(active):focus {
      // drop target green bottom border was missing
      border-bottom: 1px solid $drop_target_color;
    }

    treeview.view header button {
      background-color: if($variant=='light', $base_color, $base_color);
      background-image: none;
      border-color: transparentize($borders_color, 0.6);
      border-left: 1px;

      &:hover {background-color: $bg_color;}
      &:backdrop { background-color: $backdrop_base_color;}
    }

    .nautilus-list-view .view {
      border-bottom: 1px solid transparentize($borders_color, 0.8);

      // Hide superfluous treeview drop target indication
      &.dnd { border-style: none; }

      $_selection_bg: if($variant=='light', darken($bg_color, 5%), lighten($base_color, 5%));
      treeview {
        &:selected {
          background-color: $_selection_bg;
          color: $fg_color;
          &:hover {
            background-color: if($variant=='light', darken($_selection_bg, 5%), lighten($_selection_bg, 5%));
          }
          &:backdrop {
            color: $backdrop_fg_color;
            background-color: $_selection_bg;
          }
        }
      }
    }

    notebook > header {
      background: $bg_color;
    }

    paned > separator {
      // separator between sidebar and main window view
      background-image: image(if($variant=='light', transparentize($borders_color, 0.6), darken($borders_color, 1%)));
      &:backdrop { background-image: image(transparentize($borders_color, 0.7)); }
    }

    // custom code from nautilus Adwaita.css for entries and the pathbar
    entry.search > * {
      margin: 5px;
    }

   /*
    .path-bar-box {
      border-radius: 5px;
      border: 1px solid if($ambiance, darken($headerbar_bg_color, 9%), $borders_color);
      &:backdrop { border-color: if($ambiance, $headerbar_bg_color, $backdrop_borders_color);}
      background-color: if($ambiance, lighten($headerbar_bg_color, 6.5%), $bg_color);
      padding-right: 6px;
      &:backdrop { border-color: if($ambiance, darken($inkstone, 9%), $backdrop_borders_color); }
    }

    .nautilus-path-bar button {
      margin: 0px;
    }

    .nautilus-path-bar button:first-child {
      border-width: 0px 1px 0px 0px;
      border-radius: 3.5px 0px 0px 3.5px;
    }

    .nautilus-path-bar button:not(:first-child) {
      border-width: 0px 1px 0px 1px;
      border-radius: 0px 0px 0px 0px;
    }
    */
    .nautilus-path-bar button:not(:checked) image { opacity: 0.8; } /* dim the icon when not checked */

    // This is the Icon + Text beneath - it's one widget
    .nautilus-canvas-item {
      outline-width: 0;
      // First, remove the background
      background-color: rgba(255, 255, 255, 0.1);
      // Then bring it back for when it receives a direction
      &:selected:not(:backdrop) {
        &:dir(ltr) { background-color: $selected_bg_color; }
        &:not(:dir(ltr)) { background-color: rgba(175, 175, 175, 0.5); }
        color: $selected_fg_color;
      }

      &:backdrop:selected {
        background-color: $selected_bg_color;
        color: $backdrop_selected_fg_color;
      }
    }
}

// Nautilus disk space dialogue styling
// Copied from the nautilus adwaita.css
// keeping the CSS code style to make upstream updates easier

$_disk_space_unknown: $insensitive_bg_color;
$_disk_space_used: $progress_bg_color;
$_disk_space_free: if($variant=='light', darken($bg_color, 10%), $bg_color);

.disk-space-display {
    border-style: solid;
    border-width: 2px;
}

.disk-space-display.unknown {
    background-color: $_disk_space_unknown;
    border-color: transparentize($_disk_space_unknown, 0.7);
    color: $_disk_space_unknown;
}
.disk-space-display.unknown.border {
    color: transparentize($_disk_space_unknown, 0.7);
}

.disk-space-display.used {
    background-color: $_disk_space_used;
    border-color: transparentize($_disk_space_used, 0.7);
    color: $_disk_space_used;
}
.disk-space-display.used.border {
    color: transparentize($_disk_space_used, 0.7);
}

.disk-space-display.free {
    background-color: $_disk_space_free;
    border-color: transparentize($_disk_space_free, 0.7);
    color: $_disk_space_free;
}
.disk-space-display.free.border {
    color: transparentize($_disk_space_free, 0.7);
}

/************
 * Terminal *
 ************/

$_terminal_bg_color: #300A24;
$_terminal_fg_color: white;

terminal-window {

    // use unity 8 colors
    // only colors, let everything else be inherited
    .terminal-screen {
        // inherits from .background
        background-color: $_terminal_bg_color;
        color: $_terminal_fg_color;

        &:backdrop {
            background-color: lighten($_terminal_bg_color, 2%);
            color: $backdrop_selected_fg_color;
        }
    }

    notebook {
        scrollbar {
            // inherits from scrollbar
            background-color: transparent;
            border-color: transparent;

            &:backdrop {
                background-color: transparent;
                border-color: transparent
            }

            slider {
                // avoids scrollbar protruding from the terminal window on wayland session
                // workaround for https://bugs.launchpad.net/ubuntu/+source/gnome-terminal/+bug/1720651
                margin: 0;
                border-width: 3px;

                &:backdrop {
                  background-color: gtkalpha(currentColor, 0.1);
                }

                &:disabled {
                    background-color: transparent;
                }
            }

            &.dragging,
            &.hovering {
                background-color: transparent;
            }
        }
    }
}

  /******************
   * GNOME Software *
   ******************/
  .review-row {
    margin-bottom: 10px;
    padding: 6px 12px;
    box-shadow: 0 1px 2.5px transparentize(black, 0.75);
    outline-offset: -1px;

    &,
    &:not(:selected):not(:backdrop):hover,
    &:not(:selected):not(:backdrop):active { background-color: $base_color; }

    &:backdrop { background-color: $backdrop_base_color; }

    &:last-child { margin-bottom: 0; }

    > grid { margin-top: -24px; }
  }

  .app-listbox-header { background: $dark_fill; }

  .list-box-app-row {
    border-radius: 0;
    border-color: $borders_color;
    border-style: none solid solid solid;
    border-width: 0 1px 1px 1px;
    margin: -1px 0 0 0;

    & ~ separator {
      background-color: $bg_color;
      border: none;
      min-height: 0px;
    }
  }

  // Avoid double border when list in included in a box (e.g. Updates view)
  box > list row.list-box-app-row {
      border: none;
  }

  //Used as update count in GNOME software
  .counter-label {
    margin-top: 2px;
    margin-bottom: 2px;
    border-width: 0px;
    padding-left: 2px;
    padding-right: 2px;
    box-shadow: inset 0 0 10px 10px $success_color;
  }

  /*********
   * Gedit *
   *********/
  .gedit-bottom-panel-paned notebook > header {
      background: if($variant==light, $porcelain, $bg_color);
  }

  .gedit-bottom-panel-paned ~ statusbar {
    // give gedit's bottom panel a border
    border-top: 1px solid $borders_color;

    &:backdrop { border-color: $backdrop_borders_color; }
  }

  .gedit-search-slider {
    // gives gedit search entry some padding and a border
    // otherwise it's right under the headerbar
    background: $bg_color;
    border: 1px solid $borders_color;
    border-top-style: none;
    padding: 4px 8px;
    border-radius: 0 0 5px 5px; // same radius as tooltips

    &:backdrop {
      background-color: $backdrop_bg_color;
      border-color: $backdrop_borders_color;
    }
  }

  .gedit-search-entry-occurrences-tag {
      color: transparentize($fg_color, 0.65);
      border: none; // Removed ugly tag border
      box-shadow: none; // Removed button inset shadow
      margin: 2px;
      padding: 2px;
  }

  .gedit-document-panel { // 'documents' pane

      background-color: $bg_color;
      row.activatable { padding: 6px; }

      row button { // 'close' button
          min-width: 22px;
          min-height: 22px;
          padding: 0;
          margin: 0;
          border: none;
      }

      row:hover button {
          &:hover {
              background-color: rgba($fg_color, 0.15);
          }
          &:active {
              background-color: rgba($fg_color, 0.25);
          }
      }

      row:hover:selected button:hover {
          color: $selected_fg_color;
      }
  }

  /***************
   * GNOME Disks *
   ***************/

  headerbar button image ~ window decoration ~ menu separator {
    // gnome disks headerbar menu seems to inherit the headerbar separator bg color
    // no unique class names or id used here so this rule is as specific as it can be
    background: $borders_color;
  }

  /********
   * Nemo *
   ********/
  .nemo-properties-dialog {
    .dialog-action-box .dialog-action-area {
      // add margin to preferences buttons
      margin: 2px 6px 4px;
    }

    toolbar stackswitcher.linked button {
      margin-right: 0;
      &:backdrop {
        color: $backdrop_fg_color;
        background-color: $backdrop_bg_color;
      }
    }
  }

  .nemo-window {
    .sidebar  {
      scrolledwindow.frame.nemo-places-sidebar {
        // get rid of double border in sidebar
        border: none;
      }

      viewport.frame box.vertical treeview.view.places-treeview {
        // use sidebar bg color
        background-image: image($sidebar_bg_color);
        border-radius: 0; // get rid of weird radius on selected rows
        &:backdrop { background-image: image($backdrop_sidebar_bg_color); }
        &:selected { background: $selected_bg_color; }
        &:not(:selected) {
          &:not(:backdrop):hover { background-image: image($base_hover_color); }
        }
      }

    }

    .nemo-inactive-pane .view, .nemo-inactive-pane iconview {
      // Shades the background of the inactive pane
      background-color: $backdrop_bg_color;
    }

    .nemo-window-pane {
      widget.entry {
        // Add border around rename text entry
        border: 1px solid;
        border-radius: 3px;
        color: $fg_color;
        border-color: $selected_bg_color;
        background-color: $bg_color;
      }
      widget.entry:selected {
        // Add highlighting to selected text in rename text entry
        border: 1px solid;
        border-radius: 3px;
        color: $selected_fg_color;
        border-color: $selected_bg_color;
        background-color: $selected_bg_color;
      }
    }

    .view {
      // imports nautilus tweaks
      // dim icons in backdrop
      &:backdrop { @extend %dim_icons_in_backdrop; }
    }

    toolbar.horizontal.primary-toolbar {
      // add border under toolbar
      border-bottom: 1px solid $borders_color;

      widget.linked.raised button {
        // use proper icons for next and left in stackswitcher-like pathbar
        &:first-child widget {-gtk-icon-source: -gtk-icontheme('go-previous-symbolic'); }
        &:last-child widget {-gtk-icon-source: -gtk-icontheme('go-next-symbolic'); }
      }

      toolitem box widget * {
        // reset toolbar button dimensions
        min-height: 0;
        min-width: 0;
      }

      .linked button {
        // link linked buttons
        margin-right: 0;
      }

      button {
        // return non-flat buttons
        @each $state, $t in ("", "normal"),
        (":hover", "hover"),
        (":active, &:checked", "active"),
        (":disabled", "insensitive"),
        (":disabled:active, &:disabled:checked", "insensitive-active"),
        (":backdrop", "backdrop"),
        (":backdrop:active, &:backdrop:checked", 'backdrop-active'),
        (":backdrop:disabled", 'backdrop-insensitive'),
        (":backdrop:disabled:active, &:backdrop:disabled:checked", 'backdrop-insensitive-active') {
          &#{$state} { @include button($t) }
        }
      }
    }
  }

  /*************
  * GNOME ToDo *
  **************/

  .org-gnome-Todo {
    taskrow.activatable.new-task-row button.popup.toggle {
     border-radius: 0px;
     border: none;
     border-left: 1px solid $borders-color;
     padding-left: 10px; padding-right: 10px;
     -gtk-outline-radius: 0px;

    }

    viewport.view, listbox.transparent {
     background-color: darken($base_color,5%);
     &:backdrop { background-color: $backdrop_base_color}
    }
  }

  /***********
   * Firefox *
   ***********/
  #MozillaGtkWidget.background  {
    // REMOVE THIS when firefox supports rounded menus
    menu, .menu,.context-menu { border-radius: 0; }

    @if $ambiance {
      menubar,
      .menubar,
      menubar > menuitem:hover {
      //  background-color: $headerbar_bg_color;
      //  color:$headerbar_fg_color;
      }
    }

    // Adapt scrollbars a bit more to the GTK Scrollbar styling
    scrollbar {
      background-color: transparent;
      border-color: transparent;

      slider  {
        background-color: darken($scrollbar_slider_color, 10%);
        &:hover { background-color: darken($scrollbar_slider_hover_color, 10%); }
        &:hover:active { background-color: $scrollbar_slider_active_color; }
        &:backdrop { background-color: $backdrop_scrollbar_slider_color; }
        &:disabled { background-color: transparent; }
      }

      trough {
        background-color: transparentize($bg_color, 0.8);
      }
    }
  }

  normal-button {
    @include button(normal);

    &:hover {
      @include button(hover);
    }
    &:active { @include button(active)}

    &:disabled {@include button(insensitive);}
  }

  /***********
   * Ubiquity *
   ***********/

  #live_installer {

    #title_eventbox {
      background-color: $bg_color;
      color: $fg_color;
      &:backdrop {
        background-color: $backdrop_bg_color;
        color: $backdrop_fg_color;
      }
    }

    #dot_grid progressbar	{
      border-radius: 100%;
      padding: 1px;
      padding-top: 2px;
      background-color: white;
      border: 1px solid $progress_bg_color;

      .empty {
        border-radius: 100%;
        background-color: white;
        padding: 0px;
      }

      .full progress {
        border-radius: 100%;
        padding: 1px;
        padding-top: 2px;
        margin-bottom: 2px;
      }
    }
  }
  #dialog-action_area1 { padding-bottom: 5px; padding-right: 5px }

  /***********
   * Geary *
   ***********/

  .geary-expanded headerbar { border: none; }

  /***********
   * usb-creator-gtk *
   ***********/

   #dialog-action_area3 { margin: 5px; }

   /***********
   * Evolution *
   ***********/

   assistant.background scrolledwindow .vertical checkbutton {
     // checkbox is clipped but this is undetectable till it gets keyboard focus
     // so we're pushing it to the right to have the focus ring be displayed properly
     margin-left: 1px
  }


/***********
* Mate *
***********/
$_panel_bg_color: $bg_color;
$_panel_fg_color: $fg_color;
$_base_bg_color: if($ambiance==true, $_panel_bg_color, if($variant=='light', $bg_color, $_panel_bg_color));
$_base_fg_color:  if($ambiance==true, $_panel_fg_color, if($variant=='light', $fg_color, $_panel_fg_color));
$_backdrop_base_bg_color: lighten(if($ambiance==true, $_panel_bg_color, if($variant=='light', $bg_color, $_panel_bg_color)), 3%);
$_backdrop_base_fg_color:  transparentize(if($ambiance==true, $_panel_fg_color, if($variant=='light', $fg_color, $_panel_fg_color)), 0.3);
$_base_insensitive_fg_color: if($ambiance==true, lighten($_panel_fg_color, 10%), if($variant=='light', $insensitive_fg_color, lighten($_panel_fg_color, 10%)));
$_base_border_color: if($ambiance==true, $headerbar_border_color, if($variant=='light', $borders_color, $headerbar_border_color));
$_base_hover_color: if($ambiance==true, lighten($_panel_bg_color, 4%), if($variant=='light', darken($bg_color, 4%), lighten($_panel_bg_color, 4%)));
$_base_active_color: if($ambiance==true, darken($_panel_bg_color, 4%), if($variant=='light', darken($bg_color, 4%), darken($_panel_bg_color, 4%)));
$_wm_border: if($variant=='light', transparentize(black, 0.77), transparentize($borders_color, 0.1));
$_wm_border_backdrop: if($variant=='light', transparentize(black, 0.82), transparentize($borders_color, 0.1));
$_wm_shadow: 0 3px 9px 1px transparentize(black, 0.5), 0 0 0 1px $_wm_border; //doing borders with box-shadow;

/**************
 * Mate-Panel *
 **************/

/* the panel bar itself */
#PanelPlug,
.mate-panel-menu-bar,
PanelToplevel.background {
    background-color: $_base_bg_color;
    background-image: none;
    color: $fg_color;
    text-shadow: none;
    menu {
      border-radius: $menu_radius;
      padding: 4px 0px;
      .csd & {
        border: none; // axes borders in a composited env
        border-radius: $menu_radius;
      }
    }
}
// Axe the border under panel menubars
#PanelPlug menubar { box-shadow: none; }

/* workaround to avoid unwanted black frames behind menus if switching compositor on/off */
.mate-panel-menu-bar .window-frame.csd.popup {
    box-shadow: none;
}

// Force round menus for MATE, because they are populated from the top/bottom panels
// And thus for MATE not just "legacy" menus used in "old" applications
menubar,
.menubar {
  
  > menuitem {
    
    menu {
      &:dir(rtl), &:dir(ltr) { // specificity bump
        border-radius: $menu_radius;
      }
    }    
  }
  
  .csd.popup decoration { border-radius: $menu_radius; }
}

/* hide buttons */
PanelToplevel > widget > button {
    border-image: none;
    background-image: none;
    background: transparent;
    border-style: none;
    border-radius: 0px;
    padding: 0px;
    box-shadow: none;
    color: $_base_fg_color;
}

#PanelApplet {
    border-radius: $menu_radius;
}

PanelWidget > PanelSeparator {
    border-width: 0;
    background-color: transparent;
    color: $_base_border_color;
}

/* the grid left from wnckpager and wncktasklist */
MatePanelAppletFrameDBus > MatePanelAppletFrameDBus {
    background-image: none;
    background-color: transparent;
    background-repeat: no-repeat;
    background-position: left;
}

/* this makes text readable with all kind of wallpapers if using a transparent panel */
#PanelApplet label,
.mate-panel-menu-bar menubar > menuitem {
    color: $_base_fg_color;
    text-shadow: none;
    &:hover {
      color: $_base_fg_color;
      background-image: linear-gradient(to bottom,
                      $button_active_gradient_a,
                      $button_active_gradient_b 3px,
                      $button_active_gradient_c 4px,
                      $button_active_gradient_d 50%,
                      $button_active_gradient_e 50%,
                      $button_active_gradient_f);
    //  box-shadow: inset 0 -3px 0 0 $selected_bg_color;
    }
}

/* outlines */
window.background, /* selector where outlines are writen on GtkTrayIcon */
.mate-panel-menu-bar menubar,
.mate-panel-menu-bar button,
.mate-panel-menu-bar PanelApplet {
    outline-style: solid;
    outline-offset: -2px;
    outline-color: $focus_border_color;
}

PanelApplet.wnck-applet .wnck-pager {
    outline-style: solid;
    outline-offset: -1px;
    outline-color: $focus_border_color;
}

/* main menu */
/* set normal menubar menuitem */
.mate-panel-menu-bar menubar > menuitem {
    background-image: none;
    box-shadow: none;
}

/* set selected menubar menuitem */
.mate-panel-menu-bar menubar > menuitem:hover {
    background-color: transparent;
    background-clip: border-box;
    background-image: image($_base_hover_color);
}

/* set normal menubar menu menuitem */
.mate-panel-menu-bar menubar > menuitem > .popup.csd > menu > menuitem {
    padding: 4px 5px 4px 5px;
    border-width: 0px;
}

/* set Mate menu menuitem */
.mate-panel-menu-bar menu menuitem {
    padding: 4px 5px 4px 5px;
    border-width: 0px;
}

/* all applets */
.mate-panel-menu-bar #PanelApplet button {
  &, &.flat {
    &.toggle {
      background-color: transparent;
      color: $_base_fg_color;
      border-radius: 4px;
      border-color: $borders_color;
      border-right-width: 1px;
      border-left-width: 1px; 
      border-color: rgba(0,0,0,0.0);
      box-shadow: inset 0px 1px $borders_color,inset 0px -1px $borders_color, inset 1px 0px $borders_color,inset -1px 0px $borders_color;
      border-image: none;
      text-shadow: none;
          background-image: linear-gradient(to bottom, $button_gradient_a,$button_gradient_b 50%, $button_gradient_c 50%, $button_gradient_d );


      &:hover, &:active:hover, &:checked:hover {
        background-image: linear-gradient(to bottom,
                     $button_hover_gradient_a 5%,
                      $button_hover_gradient_b 95%,
                      $button_hover_gradient_c);
        border-color: $core_color_a;
      }

      &:checked {
        

          background-image: linear-gradient(to bottom,
                      $button_active_gradient_a,
                      $button_active_gradient_b 3px,
                      $button_active_gradient_c 4px,
                      $button_active_gradient_d 50%,
                      $button_active_gradient_e 50%,
                      $button_active_gradient_f);
      }
    }
  }
}


/* charpick */

.mate-panel-menu-bar #PanelApplet button.flat.text-button { 
& { 
     @include button(normal);
      background-color: transparent;
      color: $_base_fg_color;
      border-radius: 4px;
      border-color: $borders_color;
      border-right-width: 1px;
      border-left-width: 1px; 
      border-color: rgba(0,0,0,0.0);
      box-shadow: inset 0px 1px $borders_color,inset 0px -1px $borders_color, inset 1px 0px $borders_color,inset -1px 0px $borders_color;
      padding-left: 2px;
      padding-right: 2px
}


&:checked, &:checked:hover,&:hover:active  {
@include button(active);
background-color: transparent;
      color: $_base_fg_color;
      border-radius: 4px;
      border-color: $borders_color;
      border-right-width: 1px;
      border-left-width: 1px; 
      border-color: rgba(0,0,0,0.0);
      box-shadow: inset 0px 1px $borders_color,inset 0px -1px $borders_color, inset 1px 0px $borders_color,inset -1px 0px $borders_color;
      padding-left: 2px;
      padding-right: 2px
     }

&:hover {
 border-color: $core_color_a;
      }
}


/* clock window */
#MatePanelPopupWindow {
	border-radius: $button_radius;
}


#PanelApplet > #clock-applet-button.flat.toggle {
   background-color: transparent;
   background-image: none;
   border-color: transparent;
   border-width: 0px;
   box-shadow: none;
}

#PanelApplet > #clock-applet-button.flat.toggle:hover {
	      box-shadow: inset 0px 1px $borders_color,inset 0px -1px $borders_color, inset 1px 0px $borders_color,inset -1px 0px $borders_color;
          background-image: linear-gradient(to bottom,
                     $button_hover_gradient_a 5%,
                      $button_hover_gradient_b 95%,
                      $button_hover_gradient_c);
	}

#PanelApplet > #clock-applet-button.flat.toggle:checked {
	      box-shadow: inset 0px 1px $borders_color,inset 0px -1px $borders_color, inset 1px 0px $borders_color,inset -1px 0px $borders_color;
          background-image: linear-gradient(to bottom,
                      $button_active_gradient_a,
                      $button_active_gradient_b 3px,
                      $button_active_gradient_c 4px,
                      $button_active_gradient_d 50%,
                      $button_active_gradient_e 50%,
                      $button_active_gradient_f);
	}

/* volume applet */
.mate-panel-applet-slider,
.mate-panel-applet-slider.background {
  border-radius: $menu_radius;
  border: 1px solid $_wm_border;
  background: transparent;

  frame {
    background-color: $bg_color;
    border-radius: $menu_radius;
    padding: 1px;
    margin: 1px;

    border {
      border-image: none;
      border-style: none;
      border-radius:2px;
    }

    frame {
      background-color:transparent;
      padding: 3px;
    }

    /* brightness applet */
    button {
      padding: 4px 5px 4px 0px;
      background-image: none;
      background-color: transparent;
      border-style: none;
      border-image: none;
      color: $_base_fg_color;
      margin: 0px;
      &:checked {
       // box-shadow: inset 0 -3px 0 0 $selected_bg_color;
      }
    }
  }
}

/* mate-indicator-applet */
/* needed for a transparent panel */
#fast-user-switch-applet > #fast-user-switch-menubar {
    background-color: transparent;
}

/* Classic icon style */
.mate-panel-menu-bar {
    -PanelMenuBar-icon-visible: true;
}

/* system-monitor-applet, kill light frame border */
.multiload-applet > box.horizontal > box.vertical > frame > border {
    border-color: transparent;
}

.multiload-applet > box.horizontal > box.vertical > frame {
    box-shadow: $_wm_shadow;
}

/*****************
 * Mate-terminal *
 *****************/

/* override for pavu-control */
window.background.mate-terminal > box.vertical > notebook > header.top,
window.background.mate-terminal > box.vertical > notebook > stack > box {
    border-style: none;
    border-width: 0px;
}

/* vte use hardcoded colors as upstream, ubuntu is patched */
window.background.mate-terminal {


  scrollbar {
    &, &.vertical {
      &, &:backdrop {
        background-color: transparent;
      }
    }
    
  }

  }


// /* mate-screensaver lock dialog */

.lock-dialog {
  //  border-radius: $window_radius;
  // box-shadow: 0 0 0 1px $_wm_border, 0 2px 8px 3px $_wm_shadow;
}

// .lock-dialog frame {
//     border-radius: 0px;
//     border-style: none;
//     border-width: 0px;
// }

// .lock-dialog notebook {
//     background-color: $_base_bg_color;
// }

/******************
 * multimedia OSD *
 ******************/

MsdOsdWindow.background.osd {
	border-radius: $window_radius;
  border: 1px solid transparentize(white, 0.85);
  background-color: $osd_bg_color;
  color: $osd_fg_color;

  .trough {
    border-radius: $button_radius;
    border: none;
    background: darken($osd_fg_color, 70%);
  }

  .progressbar {
    border-radius: $button_radius;
    background-color: $osd_fg_color;
    border: none;
  }
}

.background.osd {
	color: $osd_fg_color;
	background-image: none;
	background-color: $osd_bg_color;
  border-radius: $window_radius;
  border: 1px solid transparentize(white, 0.85);

  :selected {
    background-color: $selected_bg_color;
  }
}

/**************
 * Brisk-menu *
 **************/

.brisk-menu {
  .apps-list, .categories-list, entry {
    margin: 4px;
  }

  .apps-list, .categories-list {
    border-radius: $menu_radius;
    row:selected { background-color: $selected_bg_color; color: $selected_fg_color; }
  }

  /* classic session button */
  button.flat.session-button {
      padding: 5px 6px;
      min-width: 24px;
  }

  scrolledwindow {
    border-width: 1px;
    border-style: solid;
    border-color: transparent;
    margin: 4px;
  }

  scrollbar {
    background-image: none;
    background-color: transparent;
    border-style: solid;
    border-color: transparent;
  }
}

// This should move into _tweaks.scss
// Or best would be adwaita, since there is no :hover for iconview there
iconview {
  border-radius: $button_radius;
  &:hover {
    background-color: lighten($selected_bg_color, 10%);
  }
}



/* mate-keyboard-layout-view, mate-keyboard-layout-chooser */
/* this way it styles only the border of the keys, the bg of the map itself
   use the .view class */
matekbd-keyboard-drawing {
    background-color: $_base_bg_color;
}

matekbd-keyboard-drawing:selected {
        background-color: $selected_bg_color;
        color: $selected_fg_color;
}

#xkb-layout-chooser > box.dialog-vbox > box.vertical > box.vertical > frame > border {
    border-radius: 0px;
}

scrollbar {
  background-image: none;
  background-color: transparent;
}

// Axing the border-radii for classic (not csd) dialog buttons
// So we don't end up with rounded buttons in a squared dialog frame
messagedialog.background:not(.csd) {
  .dialog-action-area button {
    border-radius: $button_radius;
    -gtk-outline-radius: $button_radius;
    border: 1px solid $borders_color;
    margin: 4px;
    margin-bottom: 6px;
    &:first-child {
      margin-left: 6px;
    }
    &:last-child {
      margin-right: 6px;
    }
  }
}

/**************
 * Caja *
 **************/

window.background.caja-navigation-window #Toolbar:backdrop { background-color: $backdrop_bg_color; }

.caja-pathbar button {
  min-width: 24px;
  border-radius: 0;
  border-right-width: 0;
  margin-right: -3px;
}

.caja-pathbar button.slider-button:nth-child(odd) {
    border-radius: $button_radius 0px 0px $button_radius;
}

.caja-pathbar button.slider-button:nth-child(even) {
    border-radius: 0 $button_radius $button_radius 0;
    border-right-width: 1px;
}

// Removes roundness and highlight from
// Headerbars that are not the last vertical top element
// of the window
.background:not(.csd) headerbar:not(.titlebar) {
  border-radius: 0;
  box-shadow: none;
}

// style mate control center
#slab_section_style2.vertical:dir(ltr)  {
  background-color: $base_color; 
  &, label {
    &, &:dir(ltr) {
      color: $text_color;
      &:backdrop { color: $backdrop_text_color; }
    }    
  }
}

// Style mate panel pull down terminal search bar
window#Main.background {
  $_pull_down_terminal_border_color: if($variant=='light', $borders_color, lighten(desaturate($base_color, 100%), 14%));
  #search {
    background: $base_color;
    color: $fg_color;
    box-shadow: inset 100px 100px $base_color; // very dirty hack, otherwise we can't set the bg
    border-bottom: 1px solid $_pull_down_terminal_border_color;
    entry { border-color: $_pull_down_terminal_border_color; }
  }
  
  
}

window > box.vertical > box.vertical > box.vertical button.text-button { padding-left: 0px; padding-right: 0px; min-width: 2px; margin: 0px; }

MatePanelAppletFrameDBus > MatePanelAppletFrameDBus {
    background-image: -gtk-scaled(url("assets/panel-grid.svg"));
    background-color: transparent;
    color: #8f8f8f;
    background-repeat: no-repeat;
    background-position: left;
}

/* for firefox and probably other apps */
label:selected,
label selection,
label selection:focus,
label selection:hover {
  color: $selected_fg_color;
}

